@@ -11,17 +11,21 @@ def get_base_path():
 
 class WaitForTestabilityKeyword(LibraryComponent):
 
-
     def __init__(self, ctx):
         LibraryComponent.__init__(self, ctx)
         self.js_keywords = JavaScriptKeywords(self.ctx)
         self.base_path = get_base_path()
-        self.READY_CALLBACK = "var readyCallback = arguments[arguments.length - 1]"
 
     @keyword
     def wait_for_testability_ready(self):
-        self.js_keywords.execute_async_javascript("{0}; window.testability.when.ready(function() {readyCallback()});".format(self.READY_CALLBACK))
+        """
+        TODO: Wait For Testability Ready keyword
+        """
+        self.js_keywords.execute_async_javascript("var readyCallback = arguments[arguments.length - 1]; window.testability.when.ready(function() {readyCallback()});")
 
-    @keyword 
+    @keyword
     def wait_for_document_ready(self):
-        self.js_keywords.execute_async_javascript("{0}; var checkReadyState=function() { document.readyState !== 'complete' ? setTimeout(checkReadyState, 11) : readyCallback();};".format(self.READY_CALLBACK))
+        """
+        TODO: Wait For Document Ready keyword
+        """
+        self.js_keywords.execute_async_javascript("var readyCallback = arguments[arguments.length - 1]; var checkReadyState=function() { document.readyState !== 'complete' ?  setTimeout(checkReadyState, 11) : readyCallback();}; checkReadyState()")
